@@ -1,4 +1,4 @@
-__version__ = "0.1.3"
+__version__ = "0.2.0"
 
 # Sigh. I want to be able to do this:
 #   >>> from redis_metrics import metric
@@ -6,5 +6,8 @@ __version__ = "0.1.3"
 # the ``redis`` dependency hasn't yet been installed.
 try:
     from .utils import gauge, metric
+    # placate pyflakes
+    assert gauge
+    assert metric
 except ImportError:
     pass
